Feed

Struct Feed 

pub struct Feed {
    pub items: Vec<FeedItem>,
    pub tags: Vec<String>,
    /* private fields */
}
Representation for single feed as retrieved from database. Used for storing both url and query based feeds.

Fields

items: Vec<FeedItem>

Article items associated with given feed.

tags: Vec<String>

Tags associated with given feed.

Implementations

Source

impl Feed

pub fn init(url: String, title: String, feedlink: String) -> Feed

Initialize new Feed using default values.

pub fn init_query_feed(title: String, line_no: usize) -> Feed

Initialize empty query feed, these feeds are composite of other feeds and filter params and are missing most of the feed parameters.

pub fn add_item(&mut self, item: FeedItem)

Add new article to the list of feed items.

pub fn sort_items(&mut self)

Sort feed items from newest to oldest.

pub fn truncated_items_count(&self) -> usize

Fetch number of items in the feed that will be held if feed is to become trunacted.

pub fn truncated_iter(&mut self) -> impl Iterator<Item = &mut FeedItem>

pub fn truncate_items(&mut self)

Compact list of articles to either 50 or week max so that we dont have to load all the articles at the same time.

pub fn update_with_url_data( &mut self, tags: Vec<String>, hidden: bool, title_override: Option<String>, line_no: usize, )

Update feed with data retrieved from urls file.

pub fn id(&self) -> &String

Custom unique id associated with the feed

pub fn url(&self) -> &String

RSS url used for retrieving feed articles.

pub fn title(&self) -> &String

Default title as retrievied from RSS feed.

pub fn display_title(&self) -> &String

User defined title (via urls file).

Site link associated with given RSS channel.

pub fn is_sorted(&self) -> bool

Whether or not feed articles have been sorted. By default articles are sorted from latest to oldest.

pub fn is_hidden(&self) -> bool

Whether or not feed is defined as hidden (via urls file)

pub fn is_query_feed(&self) -> bool

Returns whether feed is a query feed.

pub fn is_empty(&self) -> bool

Whether or not feed has any articles.

pub fn order_idx(&self) -> &usize

Order of the feed in the feed list, based on the order defined in urls file.